use <../libs/rounded_shapes.scad>
use <../libs/standoffs.scad>
include <../libs/metric_screws.scad>

make_base = false;
make_hold_down = false;

$fn = 22;
board_width = 25.4 * (3.0 + 52.5/64.0);

board_depth = 73.1;

base_thickness = 1.44;

usb_connector_width = 12.1;
usb_connector_height = 11;
usb_connector_protrusion = 5.5;
usb_connector_offset = 45.1;

wall_thickness = usb_connector_protrusion - 2.2;

margin = 2.5;

overall_width = board_width + 2*margin;

overall_depth = board_depth + 2*margin;

lower_support_frac = 0.1;
lower_support_offset = lower_support_frac * overall_width;
lower_support_width = overall_width * (1.0 - 2*lower_support_frac);

board_thickness = 25.4 * 4/54.0; 
board_clearance = 4.0;

mounting_hole_dia = 25.4 * 8/64.0;

mounting_hole_offset_from_edge = mounting_hole_dia/2.0 + (25.4 * 1/64.0);

hold_down_dim = 5.5;

mount_screw_dia = 11/64.0 * 25.4;
mount_screw_hole_radius = mount_screw_dia * 1.05 / 2.0;

zip_tie_rack_spacing = board_depth/8;
zip_tie_anchor_width = 5;
zip_tie_rack_width = 9.0;

board_overlap = 5.8;

module zip_tie_rack(){
    difference(){
 rounded_rectangle(zip_tie_rack_width,board_depth,base_thickness,1);
        
        union(){
    translate([zip_tie_rack_width/2,zip_tie_rack_spacing * 2, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 10, center = true);
    }
    
    translate([zip_tie_rack_width/2,zip_tie_rack_spacing * 6, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 10, center = true);
    }
}
    }
  translate([0,2,base_thickness]){
  difference(){
  union(){
  for(i = [0:3]){
    translate([0,zip_tie_rack_spacing * (2*i) + zip_tie_anchor_width,0]){
      cube([zip_tie_rack_width, 5, board_clearance - 1.0]);
    }
  }
  }

  translate([zip_tie_rack_width/2 - zip_tie_rack_width/4,0,0]){
    cube([zip_tie_rack_width/2.0, board_depth, board_clearance - 2.0]);
  }

    
}
}
}

if(make_base){
union(){
  translate([-1 * zip_tie_rack_width + 1,margin + wall_thickness,0]){
    zip_tie_rack();
  }
  
  translate([overall_width - 1,margin + wall_thickness,0]){
    zip_tie_rack();
  }
  difference(){
    rounded_rectangle(overall_width, wall_thickness + overall_depth + hold_down_dim, base_thickness, margin - 0.5);
    translate([overall_width/5.0, overall_depth/5.0, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 2);
    }
    
    translate([4 * overall_width/5.0, 4 * overall_depth/5.0, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 2);
    }
    
    translate([overall_width/5.0, 4 * overall_depth/5.0, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 2);
    }
    
    translate([4 * overall_width/5.0, overall_depth/5.0, -1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness + 2);
    }
    

  }
  difference(){
    translate([margin + usb_connector_offset- 0.5 - wall_thickness * 2, 0, base_thickness]){    
      cube([usb_connector_width + 0.5 + wall_thickness * 4, wall_thickness , usb_connector_height + board_clearance + board_thickness + 2.5]);
    }
    translate([margin + usb_connector_offset- 0.5,-1, base_thickness + board_clearance + board_thickness - 0.5]){
      cube([usb_connector_width+ 1, wall_thickness + 2, usb_connector_height + 1]);
    }
  }
  
  // hold down screws
  translate([0, margin + wall_thickness + board_depth + margin - 1, base_thickness]){
    translate([overall_width /6.0,0,0]){
      color("green") difference() {
        square_standoff(hold_down_dim, hold_down_dim, board_clearance + 0.05,  m3_screw_dia);        
      }
    }
    
    translate([overall_width * 5 /6.0,0,0]){
      color("green") difference() {
        square_standoff(hold_down_dim, hold_down_dim, board_clearance + 0.05,  m3_screw_dia);        
      }
    }
  }
  
  //Mounting posts
  translate([0, wall_thickness, base_thickness]){
    translate([margin + mounting_hole_offset_from_edge, margin + mounting_hole_offset_from_edge, 0]){
      color("red") peaked_mounting_post(board_clearance, mounting_hole_dia, board_thickness + 0.5);
    }
    
    translate([margin + (board_width - mounting_hole_offset_from_edge), margin + mounting_hole_offset_from_edge, 0]){
      color("red") peaked_mounting_post(board_clearance, mounting_hole_dia, board_thickness + 0.5);
    }
    
    //NOTE - calculations below may be suspect
    
    translate([margin + (board_width - mounting_hole_offset_from_edge), margin + (board_depth - mounting_hole_dia/2) - mounting_hole_offset_from_edge, 0]){
      color("red") peaked_mounting_post(board_clearance, mounting_hole_dia, board_thickness + 0.5);
    }
    

    translate([margin + mounting_hole_offset_from_edge, margin + (board_depth - mounting_hole_dia/2) - mounting_hole_offset_from_edge, 0]){
      color("red") peaked_mounting_post(board_clearance, mounting_hole_dia, board_thickness + 0.5);
    }
  }
}
}


fastener_length = 10.5;

if(make_hold_down){
translate([0,-20,0]){ 
  difference(){
    union(){
      cube([hold_down_dim * 2,hold_down_dim, board_thickness]);
      translate([-0, -1 * board_overlap,board_thickness - 0.1]){
        cube([hold_down_dim * 2, board_overlap + hold_down_dim, fastener_length - board_clearance - board_thickness]);    
      }
      translate([0,hold_down_dim, -1 * board_clearance + 1]){
        cube([hold_down_dim * 2, 2.0, fastener_length -1.1]);
      }
    }
    translate([hold_down_dim, hold_down_dim/2.0, -1]){
      cylinder(r = m3_screw_dia/2.0 * 1.29, h = 100.0); 
    }
  }
}
}

